#[non_exhaustive]pub enum AdapterErrorKind {
Other,
Buffer,
Unsupported,
}Expand description
Backend-adapter-local error classification.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Other
Error is not a shared adapter classification.
Buffer
Error is a caller buffer sizing or layout problem.
Unsupported
Error is an unsupported backend, request, input, or host capability.