Module error

Module error 

Common error classifications and helper error types.

Structs

NotImplemented
Error for a valid request that is not implemented yet.
Unsupported
Error for input or options unsupported by the current codec.

Enums

BufferError
Buffer validation and copy errors.
InputError
Generic malformed or truncated input errors.

Traits

CodecError
Shared error classification used by facade traits.