pub trait CodecError:
Error
+ Send
+ Sync
+ 'static {
// Required methods
fn is_truncated(&self) -> bool;
fn is_not_implemented(&self) -> bool;
fn is_unsupported(&self) -> bool;
fn is_buffer_error(&self) -> bool;
}Expand description
Shared error classification used by facade traits.
Required Methods
Sourcefn is_truncated(&self) -> bool
fn is_truncated(&self) -> bool
True when the error indicates truncated input.
Sourcefn is_not_implemented(&self) -> bool
fn is_not_implemented(&self) -> bool
True when the error indicates an unimplemented supported surface.
Sourcefn is_unsupported(&self) -> bool
fn is_unsupported(&self) -> bool
True when the error indicates unsupported input or options.
Sourcefn is_buffer_error(&self) -> bool
fn is_buffer_error(&self) -> bool
True when the error indicates caller buffer sizing or layout problems.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".