#[non_exhaustive]pub enum PixelFormat {
Rgb8,
Rgba8,
Gray8,
Rgb16,
Rgba16,
Gray16,
}Expand description
Concrete interleaved pixel format.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Rgb8
Interleaved 8-bit RGB.
Rgba8
Interleaved 8-bit RGBA.
Gray8
8-bit grayscale.
Rgb16
Interleaved 16-bit RGB.
Rgba16
Interleaved 16-bit RGBA.
Gray16
16-bit grayscale.
Implementations
Sourceimpl PixelFormat
impl PixelFormat
Sourcepub const fn layout(self) -> PixelLayout
pub const fn layout(self) -> PixelLayout
Return the channel layout for this pixel format.
Sourcepub const fn sample(self) -> SampleType
pub const fn sample(self) -> SampleType
Return the integer sample type for this pixel format.
Sourcepub const fn bytes_per_sample(self) -> usize
pub const fn bytes_per_sample(self) -> usize
Return the number of bytes in one channel sample.
Sourcepub const fn bytes_per_pixel(self) -> usize
pub const fn bytes_per_pixel(self) -> usize
Return the number of bytes in one interleaved pixel.