pub struct DecodeRequest {
pub roi: Option<Rect>,
pub scale: Downscale,
}Expand description
Source-region and reduced-resolution shape requested during decode.
Fields
roi: Option<Rect>Optional source-image region. None requests the full image.
scale: DownscaleReduced-resolution decode scale.
Implementations
Sourceimpl DecodeRequest
impl DecodeRequest
Sourcepub const FULL: DecodeRequest
pub const FULL: DecodeRequest
Full-image, full-resolution decode request.
Sourcepub const fn full() -> DecodeRequest
pub const fn full() -> DecodeRequest
Construct a full-image, full-resolution decode request.
Sourcepub const fn region(roi: Rect) -> DecodeRequest
pub const fn region(roi: Rect) -> DecodeRequest
Construct a full-resolution region decode request.
Sourcepub const fn scaled(scale: Downscale) -> DecodeRequest
pub const fn scaled(scale: Downscale) -> DecodeRequest
Construct a full-image scaled decode request.
Sourcepub const fn region_scaled(roi: Rect, scale: Downscale) -> DecodeRequest
pub const fn region_scaled(roi: Rect, scale: Downscale) -> DecodeRequest
Construct a region scaled decode request.
Sourcepub const fn is_full_resolution_full_image(self) -> bool
pub const fn is_full_resolution_full_image(self) -> bool
Return whether this request covers the full image at full resolution.
Sourcepub fn decoded_rect(self, dimensions: (u32, u32)) -> Rect
pub fn decoded_rect(self, dimensions: (u32, u32)) -> Rect
Return the output rectangle covered by this request for image dimensions.