CodecError

Trait CodecError 

pub trait CodecError:
    Error
    + Send
    + Sync
    + 'static {
    // Required methods
    fn is_truncated(&self) -> bool;
    fn is_not_implemented(&self) -> bool;
    fn is_unsupported(&self) -> bool;
    fn is_buffer_error(&self) -> bool;
}
Shared error classification used by facade traits.

Required Methods

fn is_truncated(&self) -> bool

True when the error indicates truncated input.

fn is_not_implemented(&self) -> bool

True when the error indicates an unimplemented supported surface.

fn is_unsupported(&self) -> bool

True when the error indicates unsupported input or options.

fn is_buffer_error(&self) -> bool

True when the error indicates caller buffer sizing or layout problems.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors