Common error classifications and helper error types.
Structs
- NotImplemented
- Error for a valid request that is not implemented yet.
- Unsupported
- Error for input or options unsupported by the current codec.
Enums
- Buffer
Error - Buffer validation and copy errors.
- Input
Error - Generic malformed or truncated input errors.
Traits
- Codec
Error - Shared error classification used by facade traits.